CollectionEffect Type
Side effect emitted when a collection update shifts the realized window (`VisibleRangeChanged`).
Union cases
| Union case |
Description
|
|
|
Side effect emitted when a collection update shifts the realized window (`VisibleRangeChanged`).
| Union case |
Description
|
|
|